@@ -2,7 +2,7 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Socket qw/AF_INET AF_INET6/;
 
@@ -83,7 +83,7 @@ Returns undef on illegal input.
 
 sub new {
   croak 'wrong method call' unless defined $_[1];
-  my $self = bless( {}, $_[0] );
+  my $self = bless( {}, ref $_[0] || $_[0]);
 
   # IPv4
   if ( index( $_[1], ':' ) < 0 ) {
@@ -114,16 +114,6 @@ sub new {
   return $self;
 }
 
-=head2 clone
-
-Clone the object.
-
-=cut
-
-sub clone {
-  return ( ref $_[0] )->new_from_bytes( $_[0]->bytes );
-}
-
 =head2 new_from_bytes
 
   $ip = Net::IPAM::IP->new_from_bytes("\x0a\x00\x00\x01")
@@ -132,11 +122,15 @@ Parse the input as packed IPv4/IPv6/IPv4-mapped-IPv6 address and returns the IP
 
 Croaks on illegal input.
 
+Can be used for cloning the object:
+
+  $clone = $obj->new_from_bytes($obj->bytes);
+
 =cut
 
 sub new_from_bytes {
   croak 'wrong method call' unless defined $_[1];
-  my $self = bless( {}, $_[0] );
+  my $self = bless( {}, ref $_[0] || $_[0] );
   my $n    = $_[1];
 
   if ( length($n) == 4 ) {
@@ -287,7 +281,7 @@ Returns the next IP address, returns undef on overflow.
 
 sub incr {
   my $n = incr_n( $_[0]->bytes ) // return;
-  return Net::IPAM::IP->new_from_bytes($n);
+  return (ref $_[0])->new_from_bytes($n);
 }
 
 =head2 expand
